@@ -9,6 +9,8 @@ import numpy as np
 import os
 import csv
 from ._version import __version__
+_seed = 1
+np.random.seed(_seed)
 
 DATASETS = {'diabetes' : ['age', 'sex', 'bmi', 'tc', 'ldl', 'hdl', 'tch', 'ltg', 'glu']}
 
@@ -20,7 +22,7 @@ MODELS = {'regression' : {'model': linear_model.LinearRegression, 'params': {}},
             'solver': 'adam', 
             'max_iter': 500,
             'tol': -1, # Always go for the specified number of iterations
-            'random_state': 1,
+            # 'random_state': 1,
             'learning_rate_init': .1, 
             'verbose': True}
             },
@@ -80,6 +82,7 @@ def train(training_x, training_y, algorithm="regression", user_params = None):
     Train a data set based on the model
     """
     # Train the model
+    np.random.seed(_seed) # force same results for all tests
     params = MODELS[algorithm]['params']
     if user_params:
         # Ensures that the student does not pass in an absurd number of iterations and
@@ -88,6 +91,8 @@ def train(training_x, training_y, algorithm="regression", user_params = None):
             user_params['max_iter'] = min(2000, user_params['max_iter'])
         for param, val in user_params.items():
             params[param] = val
+        print("All training parameters:")
+        print(params)
 
     training_obj = MODELS[algorithm]['model'](**params) 
     training_obj.fit(training_x, training_y)
@@ -152,6 +157,15 @@ def label_plot(title="title", x_label="x-axis", y_label="y-axis"):
     plt.xlabel(x_label)
     plt.ylabel(y_label)
 
+def set_random_seed(n):
+    global _seed
+    np.random.seed(n) # force same results for all tests
+    _seed = n
+
+def get_random_seed():
+    global _seed
+    return _seed
+
 # custom exceptions
 
 class InvalidDataset(Exception):
